#
# spec file for package jp2a
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?license: %global license %doc}
Name:           jp2a
Version:        1.3.2
Release:        1.1
Summary:        Converts JPEG images to ASCII
License:        GPL-2.0-only
Group:          Amusements/Toys/Graphics
URL:            https://github.com/Talinx/jp2a
Source:         https://github.com/Talinx/jp2a/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  libcurl-devel
BuildRequires:  libexif-devel
BuildRequires:  libjpeg8-devel
BuildRequires:  libpng-devel
BuildRequires:  libwebp-devel
BuildRequires:  unzip

%package bash-completion
Summary:        Bash completions scripts for jp2a
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%package zsh-completion
Summary:        Zsh completions scripts for jp2a
Supplements:    (%{name} and zsh-completion)
BuildArch:      noarch

%description
jp2a is a JPEG to ASCII converter.

%description bash-completion
This package contains the bash completions scripts for jp2a.

%description zsh-completion
This package contains the zsh completions scripts for jp2a.

%prep
%setup -q

%build
autoreconf -vi
%configure --enable-curl
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
mv %{buildroot}%{_sysconfdir}/bash_completion.d/jp2a %{buildroot}%{_datadir}/bash-completion/completions/

%check
pushd tests
make %{?_smp_mflags} check
popd

%files
%doc ChangeLog README NEWS
%license COPYING
%{_bindir}/jp2a
%{_mandir}/man1/jp2a.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/jp2a

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_jp2a

%changelog
* Tue Nov 12 2024 Sebastian Wagner <sebix@sebix.at>
- update to version 1.3.2:
  - Fix Docker image missing libexif library. Thanks to PowerMeep
  (https://github.com/PowerMeep)
- update to version 1.3.1:
  - Fix segmentation fault that can occur when trying to parse a file of an
  unsupported file type. Thanks to Balló György (https://github.com/City-busz)
* Mon Sep 23 2024 Sebastian Wagner <sebix@sebix.at>
- Update to version 1.3.0:
  - support Exif metadata (for image orientation)
  - support for WebP images
  - add option to center image in terminal
  - support for Zsh completion
* Mon Jan  8 2024 Sebastian Wagner <sebix@sebix.at>
- Update to version 1.2.0:
  * Add edge shading - edge shading can be enabled by setting the desired edge threshold with --edge-threshold=N.N.
* Mon Dec  6 2021 Sebastian Wagner <sebix@sebix.at>
- change recommendations to supplements for bash completion sub-package
* Sun Nov 28 2021 Sebastian Wagner <sebix@sebix.at>
- Split bash-completions scripts into separate package.
* Sun Nov 28 2021 Sebastian Wagner <sebix@sebix.at>
- Changed Source URL from stale https://github.com/cslarsen/jp2a to active fork https://github.com/Talinx/jp2a
* Sat Nov 20 2021 Sebastian Wagner <sebix@sebix.at>
- Update to version 1.1.1:
  - Fix memory corruption crash with very high aspect ratio, e.g. 3000:1 (#9).
* Sun Jul 11 2021 Sebastian Wagner <sebix@sebix.at>
- update to version 1.1.0:
  - support for PNG images
  - support for HTML (Living Standard) additionally to XHTML
  - (optional) support for other character encodings than ASCII
- update to version 1.0.9:
  - support for true color and 256 color palette output for terminals
  - support for bash completion
- update to version 1.0.8:
  - Fix images with very small height
- update to version 1.0.7:
  - Moved repository over to GitHub and made some corresponding changes
  - Reverted code to version 1.0.6 because of unfinished changes that didn't work.
* Mon Jul  9 2018 sebix@sebix.at
- revert to version 1.0.6, upstream withdrew the version because it was uncomplete
  see https://github.com/cslarsen/jp2a/commit/a72958075f3fb414a5a55d0a02da6789cb972f7b
  and https://github.com/cslarsen/jp2a/issues/8
* Mon Oct  2 2017 jengelh@inai.de
- Remove pointless ldconfig calls.
* Sat Sep 30 2017 sebix@sebix.at
- Remove dependency curl
* Wed Sep  6 2017 sebix@sebix.at
- initial package for version 1.0.7
